@@ -65,18 +65,19 @@ qx.Class.define("callbackery.ui.Login", {
             });
         }
 
+	if (! cfg.hide_password) {
+            this.add(new qx.ui.basic.Image("icon/64/status/dialog-password.png").set({
+		alignY : 'top',
+		alignX : 'right'
+            }),
+            {
+		row     : 2,
+		column  : 0,
+		rowSpan : 2
+            });
+	}
 
-        this.add(new qx.ui.basic.Image("icon/64/status/dialog-password.png").set({
-            alignY : 'top',
-            alignX : 'right'
-        }),
-        {
-            row     : 2,
-            column  : 0,
-            rowSpan : 2
-        });
-
-        this.add(new qx.ui.basic.Label(this.tr("Login")), {
+        this.add(new qx.ui.basic.Label(this.tr("User")), {
             row    : 2,
             column : 1
         });
@@ -90,21 +91,26 @@ qx.Class.define("callbackery.ui.Login", {
             column : 2
         });
 
-        this.add(new qx.ui.basic.Label(this.tr("Password")), {
-            row    : 3,
-            column : 1
-        });
+	var login;
+	if (! cfg.hide_password) {
+            this.add(new qx.ui.basic.Label(this.tr("Password")), {
+                row    : 3,
+		column : 1
+            });
 
-        var password = new qx.ui.form.PasswordField();
-        password.getContentElement().setAttribute("name", "cbPassword");
-        password.getContentElement().setAttribute("autocomplete", "on");
+            var password = new qx.ui.form.PasswordField();
+            password.getContentElement().setAttribute("name", "cbPassword");
+            password.getContentElement().setAttribute("autocomplete", "on");
 
-        this.add(password, {
-            row    : 3,
-            column : 2
-        });
-
-        var login = new qx.ui.form.Button("Login", "icon/16/actions/dialog-ok.png");
+            this.add(password, {
+                row    : 3,
+		column : 2
+            });
+            login = new qx.ui.form.Button(this.tr("Login"), "icon/16/actions/dialog-ok.png");
+	}
+	else {
+            login = new qx.ui.form.Button(this.tr("OK"), "icon/16/actions/dialog-ok.png");
+	}
 
         login.set({
             marginTop  : 6,
@@ -117,9 +123,9 @@ qx.Class.define("callbackery.ui.Login", {
             column  : 0,
             colSpan : 3
         });
-        var who = '';
-        if ( cfg.company_name ){
-            who = '<br/>created by ';
+
+        if ( cfg.company_name && !cfg.hide_company){
+	    var who = '';
             if (cfg.company_url){
                 who += '<a href="' + cfg.company_url + '" style="color: #444;" target="_blank">' + cfg.company_name + '</a>';
             }
@@ -127,14 +133,16 @@ qx.Class.define("callbackery.ui.Login", {
                 who += cfg.company_name;
             }
         }
-        this.add(new qx.ui.basic.Label(this.tr('release %1, %2%3','#VERSION#','#DATE#',who)).set({
-            textColor : '#444',
-            rich : true
-        }), {
-            row    : 5,
-            column : 0,
-            colSpan: 3
-        });
+	if (! cfg.hide_release) {
+            this.add(new qx.ui.basic.Label(this.tr('release %1, %2 by %3','#VERSION#','#DATE#',who)).set({
+                textColor : '#444',
+		rich : true
+            }), {
+		row    : 5,
+		column : 0,
+		colSpan: 3
+            });
+	}
 
         this.addListener('keyup', function(e) {
             if (e.getKeyIdentifier() == 'Enter') {
@@ -150,16 +158,22 @@ qx.Class.define("callbackery.ui.Login", {
             var id = this.__getIframe();
             // save the username and password to our hidden iframe form
             id.getElementById("cbUsername").value = username.getValue();
-            id.getElementById("cbPassword").value = password.getValue();
+	    var passwordValue;
+	    if (! cfg.hide_password) {
+		passwordValue = password.getValue();
+		id.getElementById("cbPassword").value = passwordValue;
+	    }
             rpc.callAsync(qx.lang.Function.bind(this.__loginHandler, this), 'login',
                 username.getValue(),
-                password.getValue()
+                passwordValue
             );
         },
         this);
 
         this.addListener('appear', function() {
-            password.setValue('');
+	    if (! cfg.hide_password) {
+		password.setValue('');
+	    }
             this.setEnabled(true);
             if (username.getValue()){
                 username.set({
@@ -167,8 +181,10 @@ qx.Class.define("callbackery.ui.Login", {
                     readOnly: true,
                     focusable: false
                 });
-                password.focus();
-                password.activate();
+		if (! cfg.hide_password) {
+                    password.focus();
+                    password.activate();
+		}
             }
             else {
                 username.focus();
